==> openshift-model-console-5.12.4-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleQuickStartSpecBuilder.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ConsoleQuickStartSpecBuilder extends io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartSpecFluentImpl<io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartSpec,io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartSpecBuilder>{
  public ConsoleQuickStartSpecBuilder() {
    this(false);
  }
  public ConsoleQuickStartSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new ConsoleQuickStartSpec(), validationEnabled);
  }
  public ConsoleQuickStartSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ConsoleQuickStartSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ConsoleQuickStartSpec(), validationEnabled);
  }
  public ConsoleQuickStartSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartSpecFluent<?> fluent,io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartSpec instance) {
    this(fluent, instance, false);
  }
  public ConsoleQuickStartSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartSpecFluent<?> fluent,io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAccessReviewResources(instance.getAccessReviewResources()); 
    fluent.withConclusion(instance.getConclusion()); 
    fluent.withDescription(instance.getDescription()); 
    fluent.withDisplayName(instance.getDisplayName()); 
    fluent.withDurationMinutes(instance.getDurationMinutes()); 
    fluent.withIcon(instance.getIcon()); 
    fluent.withIntroduction(instance.getIntroduction()); 
    fluent.withNextQuickStart(instance.getNextQuickStart()); 
    fluent.withPrerequisites(instance.getPrerequisites()); 
    fluent.withTags(instance.getTags()); 
    fluent.withTasks(instance.getTasks()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ConsoleQuickStartSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartSpec instance) {
    this(instance,false);
  }
  public ConsoleQuickStartSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAccessReviewResources(instance.getAccessReviewResources()); 
    this.withConclusion(instance.getConclusion()); 
    this.withDescription(instance.getDescription()); 
    this.withDisplayName(instance.getDisplayName()); 
    this.withDurationMinutes(instance.getDurationMinutes()); 
    this.withIcon(instance.getIcon()); 
    this.withIntroduction(instance.getIntroduction()); 
    this.withNextQuickStart(instance.getNextQuickStart()); 
    this.withPrerequisites(instance.getPrerequisites()); 
    this.withTags(instance.getTags()); 
    this.withTasks(instance.getTasks()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartSpec build() {
    ConsoleQuickStartSpec buildable = new ConsoleQuickStartSpec(fluent.getAccessReviewResources(),fluent.getConclusion(),fluent.getDescription(),fluent.getDisplayName(),fluent.getDurationMinutes(),fluent.getIcon(),fluent.getIntroduction(),fluent.getNextQuickStart(),fluent.getPrerequisites(),fluent.getTags(),fluent.getTasks());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsoleQuickStartSpecBuilder that = (ConsoleQuickStartSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-console-6.5.0-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleQuickStartSpecBuilder.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ConsoleQuickStartSpecBuilder extends ConsoleQuickStartSpecFluentImpl<ConsoleQuickStartSpecBuilder> implements VisitableBuilder<ConsoleQuickStartSpec,ConsoleQuickStartSpecBuilder>{
  public ConsoleQuickStartSpecBuilder() {
    this(false);
  }
  public ConsoleQuickStartSpecBuilder(Boolean validationEnabled) {
    this(new ConsoleQuickStartSpec(), validationEnabled);
  }
  public ConsoleQuickStartSpecBuilder(ConsoleQuickStartSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ConsoleQuickStartSpecBuilder(ConsoleQuickStartSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ConsoleQuickStartSpec(), validationEnabled);
  }
  public ConsoleQuickStartSpecBuilder(ConsoleQuickStartSpecFluent<?> fluent,ConsoleQuickStartSpec instance) {
    this(fluent, instance, false);
  }
  public ConsoleQuickStartSpecBuilder(ConsoleQuickStartSpecFluent<?> fluent,ConsoleQuickStartSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAccessReviewResources(instance.getAccessReviewResources()); 
    fluent.withConclusion(instance.getConclusion()); 
    fluent.withDescription(instance.getDescription()); 
    fluent.withDisplayName(instance.getDisplayName()); 
    fluent.withDurationMinutes(instance.getDurationMinutes()); 
    fluent.withIcon(instance.getIcon()); 
    fluent.withIntroduction(instance.getIntroduction()); 
    fluent.withNextQuickStart(instance.getNextQuickStart()); 
    fluent.withPrerequisites(instance.getPrerequisites()); 
    fluent.withTags(instance.getTags()); 
    fluent.withTasks(instance.getTasks()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ConsoleQuickStartSpecBuilder(ConsoleQuickStartSpec instance) {
    this(instance,false);
  }
  public ConsoleQuickStartSpecBuilder(ConsoleQuickStartSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAccessReviewResources(instance.getAccessReviewResources()); 
    this.withConclusion(instance.getConclusion()); 
    this.withDescription(instance.getDescription()); 
    this.withDisplayName(instance.getDisplayName()); 
    this.withDurationMinutes(instance.getDurationMinutes()); 
    this.withIcon(instance.getIcon()); 
    this.withIntroduction(instance.getIntroduction()); 
    this.withNextQuickStart(instance.getNextQuickStart()); 
    this.withPrerequisites(instance.getPrerequisites()); 
    this.withTags(instance.getTags()); 
    this.withTasks(instance.getTasks()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ConsoleQuickStartSpecFluent<?> fluent;
  Boolean validationEnabled;
  public ConsoleQuickStartSpec build() {
    ConsoleQuickStartSpec buildable = new ConsoleQuickStartSpec(fluent.getAccessReviewResources(),fluent.getConclusion(),fluent.getDescription(),fluent.getDisplayName(),fluent.getDurationMinutes(),fluent.getIcon(),fluent.getIntroduction(),fluent.getNextQuickStart(),fluent.getPrerequisites(),fluent.getTags(),fluent.getTasks());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
